// lib/models/mal-error.model.ts
var MalValidationErrorTypes = {
  MalValidationError: "MalValidationError",
  MalNaNValidationError: "MalNaNValidationError",
  MalMinValidationError: "MalMinValidationError",
  MalMaxValidationError: "MalMaxValidationError",
  MalMinMaxValidationError: "MalMinMaxValidationError"
};
var MalErrorTypes = {
  MalFilterError: "MalFilterError",
  MalInvalidParameterError: "MalInvalidParameterError",
  MalPollingExpiredError: "MalPollingExpiredError",
  MalExpiredTokenError: "MalExpiredTokenError",
  MalRateLimitError: "MalRateLimitError",
  MalInvalidCsrfError: "MalInvalidCsrfError",
  ...MalValidationErrorTypes
};
var MalValidationError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalValidationErrorTypes.MalValidationError;
  }
};
var MalNaNValidationError = class extends MalValidationError {
  type = MalValidationErrorTypes.MalNaNValidationError;
  constructor(value, name) {
    super(`Expected a valid number${name ? ` for '${name}'` : ""}, but received '${value}'.`);
  }
};
var MalMinValidationError = class extends MalValidationError {
  type = MalValidationErrorTypes.MalMinValidationError;
  constructor({ value, min, name }) {
    super(`Expected a number less than or equal to '${min}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);
  }
};
var MalMaxValidationError = class extends MalValidationError {
  type = MalValidationErrorTypes.MalMaxValidationError;
  constructor({ value, max, name }) {
    super(`Expected a number more than or equal to '${max}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);
  }
};
var MalMinMaxValidationError = class extends MalValidationError {
  type = MalValidationErrorTypes.MalMinMaxValidationError;
  constructor({ value, min, max, name }) {
    super(`Expected a number between '${min}' and '${max}'${name ? ` for '${name}'` : ""}, but received '${value}'.`);
  }
};
var MalFilterError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalErrorTypes.MalFilterError;
  }
};
var MalInvalidParameterError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalErrorTypes.MalInvalidParameterError;
  }
};
var MalPollingExpiredError = class extends Error {
  constructor(message) {
    super(message);
    this.name = MalErrorTypes.MalPollingExpiredError;
  }
};
var MalExpiredTokenError = class extends Error {
  /**
   * Inner error that this error wraps.
   */
  error;
  constructor(message, error) {
    super(message);
    this.name = MalErrorTypes.MalExpiredTokenError;
    this.error = error;
  }
};
var MalRateLimitError = class extends Error {
  /**
   * Inner error that this error wraps.
   */
  error;
  constructor(message, error) {
    super(message);
    this.name = MalErrorTypes.MalRateLimitError;
    this.error = error;
  }
};
var MalInvalidCsrfError = class extends Error {
  state;
  expected;
  constructor({ state, expected } = {}) {
    super(`Invalid CSRF (State): expected '${expected}', but received ${state}`);
    this.name = MalErrorTypes.MalInvalidCsrfError;
    this.state = state;
    this.expected = expected;
  }
};

export {
  MalValidationErrorTypes,
  MalErrorTypes,
  MalValidationError,
  MalNaNValidationError,
  MalMinValidationError,
  MalMaxValidationError,
  MalMinMaxValidationError,
  MalFilterError,
  MalInvalidParameterError,
  MalPollingExpiredError,
  MalExpiredTokenError,
  MalRateLimitError,
  MalInvalidCsrfError
};
